MethodChannelOpenIdConnect class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authorizeInteractive({required BuildContext context, required String title, required String authorizationUrl, required String redirectUrl, required int popupWidth, required int popupHeight, bool useWebRedirectLoop = false}) → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processStartup() → Future<String?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited